MCupertinoActionSheet class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MCupertinoActionSheet
Constructors
-
MCupertinoActionSheet({Key? key, Widget? title, Widget? message, List<
Widget> ? actions, List<String> ? actionsText, Color? actionsTextColor, double? actionsFontSize, ScrollController? messageScrollController, ScrollController? actionScrollController, Widget? cancelButton, String? cancelText, Color? cancelTextColor, double? cancelFontSize, double? cancelRadius, bool hasCancelButton = false, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? cancelPadding, double? radius, BorderRadius? borderRadius, Color? actionsColor, Color? actionsDarkColor, Color? dividerColor, Color? dividerDarkColor, VoidCallback? cancelCallBack, ValueChanged? actionsCallBack}) -
const
Properties
-
actions
→ List<
Widget> ? -
final
- actionsCallBack → ValueChanged?
-
final
- actionsColor → Color?
-
final
- actionScrollController → ScrollController?
-
final
- actionsDarkColor → Color?
-
final
- actionsFontSize → double?
-
final
-
actionsText
→ List<
String> ? -
final
- actionsTextColor → Color?
-
final
- borderRadius → BorderRadius?
-
final
- cancelButton → Widget?
-
final
- cancelCallBack → VoidCallback?
-
final
- cancelFontSize → double?
-
final
- cancelPadding → EdgeInsetsGeometry?
-
final
- cancelRadius → double?
-
final
- cancelText → String?
-
final
- cancelTextColor → Color?
-
final
- dividerColor → Color?
-
final
- dividerDarkColor → Color?
-
final
- hasCancelButton → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- message → Widget?
-
final
- messageScrollController → ScrollController?
-
final
- padding → EdgeInsetsGeometry?
-
final
- radius → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → Widget?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MCupertinoActionSheet> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited